@@ -1,9 +1,8 @@
 import configparser
+import logging
 import os
 
-from .utils.logger import get_logger
-
-logger = get_logger(__name__)
+logger = logging.getLogger("packt")
 
 
 class ConfigurationModel(object):
